#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boring
version:              0.2.2
visibility:           public
id:                   boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
key:                  boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/boring
synopsis:             Boring and Absurd types
description:
    * @Boring@ types are isomorphic to @()@.

    * @Absurd@ types are isomorphic to @Void@.

    See [What does () mean in Haskell -answer by Conor McBride](https://stackoverflow.com/questions/33112439/what-does-mean-in-haskell/33115522#33115522)

category:             Data
abi:                  9e197c537958429bb8e45bf4de229a5f
exposed:              True
exposed-modules:      Data.Boring
import-dirs:          /usr/lib/ghc-9.6.6/site-local/boring-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/boring-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/boring-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boring
hs-libraries:         HSboring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
depends:
    base-4.18.2.1 tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-boring/html/boring.haddock
haddock-html:         /usr/share/doc/haskell-boring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

